[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- object: The most base type
  - exceptions.BaseException: Common base class for all exceptions
    - exceptions.Exception: Common base class for all non-exit exceptions.
      - exceptions.StandardError: Base class for all standard Python exceptions that do not represent interpreter exiting.
        - exceptions.ValueError: Inappropriate argument value (of correct type).
          - upoints.utils.FileFormatError: Error object for data parsing error
          - edist.LocationsError: Error object for data parsing error
  - upoints.point.Point: Simple class for representing a location on a sphere
    - upoints.baken.Baken: Class for representing location from baken data files
    - upoints.cellid.Cell: Class for representing a cellular cite from OpenCellID.org
    - upoints.nmea.Fix: Class for representing a GPS NMEA-formatted system fix
    - upoints.nmea.LoranPosition: Class for representing a GPS NMEA-formatted Loran-C position
    - upoints.osm.Node: Class for representing a node element from OSM data files
    - edist.NumberedPoint: Class for representing locations from command line
    - upoints.nmea.Position: Class for representing a GPS NMEA-formatted position
    - upoints.trigpoints.Trigpoint: Class for representing a location from a trigpoint marker file
      - upoints.cities.City: Class for representing an entry from the GNU miscfiles cities data file
      - upoints.geonames.Location: Class for representing a location from a geonames.org data file
      - upoints.kml.Placemark: Class for representing a Placemark element from KML data files
      - upoints.weather_stations.Station: Class for representing a weather station from a NOAA data file
    - upoints.nmea.Waypoint: Class for representing a NMEA-formatted waypoint
    - upoints.xearth.Xearth: Class for representing a location from a Xearth marker
    - upoints.tzdata.Zone: Class for representing timezone descriptions from zoneinfo data
    - upoints.gpx._GpxElem: Abstract class for representing an element from GPX data files
      - upoints.gpx.Trackpoint: Class for representing a waypoint element from GPX data files
      - upoints.gpx.Waypoint: Class for representing a waypoint element from GPX data files
  - datetime.date: date(year, month, day) --> date object
    - datetime.datetime: datetime(year, month, day[, hour[, minute[, second[, microsecond[,tzinfo]]]]])
      - upoints.osm.Timestamp: Class for representing an OSM timestamp value
  - dict: dict() -> new empty dictionary.
    - upoints.point.KeyedPoints: Class for representing a keyed group of Point objects
      - upoints.baken.Bakens: Class for representing a group of Baken objects
      - upoints.cellid.Cells: Class for representing a group of Cell objects
      - upoints.kml.Placemarks: Class for representing a group of Placemark objects
      - upoints.weather_stations.Stations: Class for representing a group of Station objects
      - upoints.trigpoints.Trigpoints: Class for representing a group of Trigpoint objects
      - upoints.xearth.Xearths: Class for representing a group of Xearth objects
  - list: list() -> new list list(sequence) -> new list initialized from sequence's items
    - upoints.point.Points: Class for representing a group of Point objects
      - upoints.cities.Cities: Class for representing a group of City objects
      - upoints.nmea.Locations: Class for representing a group of GPS location objects
      - upoints.geonames.Locations: Class for representing a group of Location objects
      - edist.NumberedPoints: Class for representing a group of NumberedPoint objects
      - upoints.osm.Osm: Class for representing an OSM region
      - upoints.osm.Way: Class for representing a way element from OSM data files
      - upoints.gpx.Waypoints: Class for representing a group of Waypoint objects
      - upoints.tzdata.Zones: Class for representing a group of Zone objects
    - upoints.gpx.Trackpoints: Class for representing a group of Trackpoint objects
  - datetime.tzinfo: Abstract base class for time zone info objects.
    - upoints.osm.TzOffset: Time offset from UTC